@@ -1,37 +1,30 @@
 # -*- coding: utf-8 -*-
 import json
 import os
-import sys
+from urllib.request import urlopen
 
 PACKAGE_DIR = os.path.abspath(os.path.dirname(__file__))
 
-if sys.version_info < (3,):
-    import codecs
-    from urllib2 import urlopen
 
-    def u(x):
-        return codecs.unicode_escape_decode(x)[0]
+def u(x):
+    return x
 
-    def get(url, timeout=None):
-        return urlopen(url, timeout=timeout)
 
-else:
-    from urllib.request import urlopen
-
-    def u(x):
-        return x
-
-    def get(url, timeout=None):
-        return urlopen(url, timeout=timeout).read().decode('utf-8').split('\n')
+def get(url, timeout=None):
+    return urlopen(url, timeout=timeout).read().decode('utf-8').split('\n')
 
 
 def path(filename):
-    """Returns a file path relative to this package directory.
+    """Returns a file path relative to the data directory.
+
+    This is the package directory by default, or the env variable
+    CONFUSABLE_DATA if set.
 
     :return: A file path string.
     :rtype: str
     """
-    return os.path.join(PACKAGE_DIR, filename)
+    data_dir = os.environ.get("CONFUSABLE_DATA", PACKAGE_DIR)
+    return os.path.join(data_dir, filename)
 
 
 def load(filename):
